@@ -6,20 +6,17 @@
 #.##......##..##....##....##..##..##..##..##......##..........##.#
 #.##......##..##....##....##..##...####...######..######...####..#
 #................................................................#
-#                                                                #
+
 # PlanetaRY spanGLES                                             #
-# The bright-side of the light-curve of (ringed) exoplanets      #
 #                                                                #
 ##################################################################
-# Jorge I. Zuluaga, Mario Sucerquia, Jaime A. Alvarado (C) 2022  #
+# License http://github.com/seap-udea/pryngles-public            #
+##################################################################
+# Main contributors:                                             #
+#   Jorge I. Zuluaga, Mario Sucerquia, Jaime A. Alvarado         #
 ##################################################################
-# --Test--
-
-# ### Test
-
-from pryngles import *
-from pryngles.legacy import *
 import unittest
+from pryngles import *
 class Test(unittest.TestCase):
 
     ##############################################################################
@@ -48,23 +45,11 @@ class Test(unittest.TestCase):
     def test_system_ensamble(self):
 
             sys=System()
-            S=sys.add(kind="Star",
-                      physics=dict(radius=Const.Rsun/Const.au))
-            P=sys.add(kind="Planet",primary=S,
-                      orbit=dict(a=0.2,e=0.0),
-                      physics=dict(radius=Const.Rsat/Const.au)
-                     )
-            R=sys.add(kind="Ring",primary=P,
-                      physics=dict(fi=1.5,fe=2.5,i=30*DEG)
-                     )
-            O=sys.add(kind="Observer",
-                      optics=dict(beta=30*DEG,lamb=90*DEG)
-                     )
+            S=sys.add("Star",name="Star",radius=Const.Rsun/Const.au)
+            P=sys.add("Planet",name="Planet",parent=S,a=0.2,e=0.0,radius=Const.Rsat/Const.au)
+            R=sys.add("Ring",name="Ring",parent=P,fi=1.5,fe=2.5,i=30*DEG)
 
-            print(S.physics.radius,P.physics.radius,R.physics.fi,R.physics.fe,P.orbit.a,P.orbit.e)
-            print(O.optics.beta,O.optics.lamb)
-
-            P=sys.ensamble_system()
+            P=sys.ensamble_system(beta=30*DEG,lamb=90*DEG)
             fig1,fig2,fig3=P.plotRingedPlanet(showfig=0)
 
             P.changeObserver([90*DEG,30*DEG])
@@ -813,3 +798,5 @@ class Test(unittest.TestCase):
 if __name__=="__main__":
     unittest.main(argv=['first-arg-is-ignored'],exit=False)
 
+# ### The End
+
